CreateTypeRequest

Struct CreateTypeRequest 

pub struct CreateTypeRequest {
    pub code: String,
    pub can_be_root: bool,
    pub allowed_parent_types: Vec<String>,
    pub allowed_membership_types: Vec<String>,
    pub metadata_schema: Option<Value>,
}
Request body for creating a new GTS type.

Fields

code: String

GTS type path. Must have prefix gts.cf.core.rg.type.v1~.

Whether this creates a new tenant scope is derived from the code: any type whose path starts with TENANT_RG_TYPE_PATH is a tenant type (tenant_id = group.id for its instances).

can_be_root: bool

Whether groups of this type can be root nodes.

allowed_parent_types: Vec<String>

GTS type paths of allowed parent types.

allowed_membership_types: Vec<String>

GTS type paths of allowed membership resource types.

metadata_schema: Option<Value>

Optional JSON Schema for instance metadata.